@@ -23,9 +23,6 @@ use parent qw/Amon2/;
 our $VERSION='0.01';
 use 5.008001;
 
-use Amon2::Config::Simple;
-sub load_config { Amon2::Config::Simple->load(shift) }
-
 # __PACKAGE__->load_plugin(qw/DBI/);
 
 1;
@@ -143,14 +140,6 @@ any '/' => sub {
     'Text::Xslate' => +{
     },
 };
-...
-
-    $self->write_file("lib/<<PATH>>/ConfigLoader.pm", <<'...');
-package <% $module %>::ConfigLoader;
-use strict;
-use warnings;
-use parent 'Amon2::ConfigLoader';
-1;
 ...
 
     $self->write_file("sql/my.sql", '');
@@ -162,7 +151,7 @@ use parent 'Amon2::ConfigLoader';
 <hr class="space">
 
 <div class="span-15 colborder">
-    <h1>hello, Amon2 world!</h1>
+    <h1>Hello, Amon2 world!</h1>
 
     <h2>For benchmarkers...</h2>
     <p>If you want to benchmarking between Plack based web application frameworks, you should use <B>Amon2::Setup::Flavor::Minimum</B> instead.</p>
